"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTenantUrl = exports.isCustomClient = void 0;
exports.isSecretConsistent = isSecretConsistent;
const config_1 = require("../../config");
const constants_1 = require("../../constants");
// Pre-delivered OAuth Client ID: 5a638330-5899-366e-ac00-ab62cc32dcda
// Custom OAuth Client ID: sb-00bb7bc2-cc32-423c-921c-2abdee11a29d!b49931|client!b3650
const isCustomClient = (clientId) => clientId ? clientId.startsWith("sb-") : true;
exports.isCustomClient = isCustomClient;
const getTenantUrl = () => {
    const config = (0, config_1.get)();
    const tenantUrl = config.tenantUrl ?? config.options[constants_1.OPTION_HOST.longName];
    if (!tenantUrl) {
        throw new Error("no tenant url found");
    }
    return tenantUrl;
};
exports.getTenantUrl = getTenantUrl;
function isSecretConsistent(secret) {
    // all these properties must exist
    return ((!!secret.tenantUrl ||
        (!!secret.authorization_url && !!secret.token_url)) &&
        (!!secret.access_token ||
            (!!secret.refresh_token && !!secret.client_id && !!secret.client_secret)));
}
