"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.create = void 0;
const next_1 = require("../../../next");
const options_1 = require("../../../options");
const constants_1 = require("../../../../../constants");
const logger_1 = require("../../../../../logger");
const utils_1 = require("../utils");
const utils_2 = require("./utils");
const SecretsStorageSingleton_1 = require("../../../../../cache/secrets/SecretsStorageSingleton");
const getLogger = () => (0, logger_1.get)("commands.handler.authentication.oauth.tokenProvider.getToken");
const handler = async () => async () => {
    const { info: logInfo, debug } = getLogger();
    logInfo("checking token existence");
    const secrets = await SecretsStorageSingleton_1.SecretsStorageSingleton.SINGLETON.getDefaultSecret();
    if (!secrets.access_token && !secrets.refresh_token) {
        debug("access token not available, retrieving token from server");
        const code = await (0, utils_2.getCode)(secrets.authorization_url, secrets.client_id);
        debug("code received, reading token");
        await (0, utils_1.readToken)({
            code,
            grant_type: "authorization_code",
        });
    }
    else if (secrets.access_token) {
        debug("token available");
    }
    else {
        throw new Error("access token not available");
    }
};
const create = () => (0, next_1.create)("commands.handler.authentication.oauth.tokenProvider.getToken", (0, options_1.create)(constants_1.OPTION_CODE), handler);
exports.create = create;
